# Table of Contents

- [Table of Contents](#table-of-contents)
- [Measurement Data Services API for Python](#measurement-data-services-api-for-python)
- [About](#about)
  - [Operating System Support](#operating-system-support)
  - [Python Version Support](#python-version-support)
  - [Installation](#installation)

# Measurement Data Services API for Python

`datastore-python` contains Python code for writing to and reading from
[NI Measurement Data Services](https://github.com/ni/datastore-service).
It will include examples of how to use the Python API.

# About

`ni.datastore` is the main Python package in this repo that
provides APIs for publishing and retrieving data from the NI
Measurement Data Services

NI created and supports this package.

## Operating System Support

`ni.datastore` supports Windows and Linux operating systems.

## Python Version Support

`ni.datastore` supports CPython 3.10+.

## Installation

As a prerequisite to using the `ni.datastore` module, you must install Measurement Data Services
Software 2026 Q1 or later on your system. You can download and install this software using
[NI Package Manager](https://www.ni.com/en/support/downloads/software-products/download.package-manager.html).

You can directly install the `ni.datastore` package using `pip` or by listing it as a
dependency in your project's `pyproject.toml` file.
